@@ -39,6 +39,8 @@
  * innecessary API/ABI breaks.
  */
 
+#ifndef QMI_DISABLE_DEPRECATED
+
 /**
  * qmi_message_dms_set_service_programming_code_input_get_new:
  * @self: a #QmiMessageDmsSetServiceProgrammingCodeInput.
@@ -115,6 +117,10 @@ gboolean qmi_message_dms_set_service_programming_code_input_set_current (
     const gchar *arg_current,
     GError **error);
 
+/* The following type exists just so that we can get deprecation warnings */
+G_DEPRECATED
+typedef int QmiDeprecatedNasSimRejectState;
+
 /**
  * QMI_NAS_SIM_REJECT_STATE_SIM_VAILABLE:
  *
@@ -123,8 +129,11 @@ gboolean qmi_message_dms_set_service_programming_code_input_set_current (
  * Since: 1.0
  * Deprecated: 1.14.0: Use the correct #QMI_NAS_SIM_REJECT_STATE_SIM_AVAILABLE name instead.
  */
-G_DEPRECATED_FOR (QMI_NAS_SIM_REJECT_STATE_SIM_AVAILABLE)
-#define QMI_NAS_SIM_REJECT_STATE_SIM_VAILABLE QMI_NAS_SIM_REJECT_STATE_SIM_AVAILABLE
+#define QMI_NAS_SIM_REJECT_STATE_SIM_VAILABLE (QmiDeprecatedNasSimRejectState) QMI_NAS_SIM_REJECT_STATE_SIM_AVAILABLE
+
+/* The following type exists just so that we can get deprecation warnings */
+G_DEPRECATED
+typedef int QmiDeprecatedWdsCdmaCauseCode;
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_VACANT:
@@ -134,8 +143,7 @@ G_DEPRECATED_FOR (QMI_NAS_SIM_REJECT_STATE_SIM_AVAILABLE)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_VACANT name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_VACANT)
-#define QMI_WDS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_VACANT QMI_WMS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_VACANT
+#define QMI_WDS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_VACANT (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_VACANT
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_TRANSLATION_FAILURE:
@@ -145,8 +153,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_VACANT)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_TRANSLATION_FAILURE name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_TRANSLATION_FAILURE)
-#define QMI_WDS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_TRANSLATION_FAILURE QMI_WMS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_TRANSLATION_FAILURE
+#define QMI_WDS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_TRANSLATION_FAILURE (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_TRANSLATION_FAILURE
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_NETWORK_RESOURCE_SHORTAGE:
@@ -156,8 +163,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_NETWORK_ADDRESS_TRANSLATION_FAILURE)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_NETWORK_RESOURCE_SHORTAGE name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_NETWORK_RESOURCE_SHORTAGE)
-#define QMI_WDS_CDMA_CAUSE_CODE_NETWORK_RESOURCE_SHORTAGE QMI_WMS_CDMA_CAUSE_CODE_NETWORK_RESOURCE_SHORTAGE
+#define QMI_WDS_CDMA_CAUSE_CODE_NETWORK_RESOURCE_SHORTAGE (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_NETWORK_RESOURCE_SHORTAGE
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_NETWORK_FAILURE:
@@ -167,8 +173,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_NETWORK_RESOURCE_SHORTAGE)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_NETWORK_FAILURE name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_NETWORK_FAILURE)
-#define QMI_WDS_CDMA_CAUSE_CODE_NETWORK_FAILURE QMI_WMS_CDMA_CAUSE_CODE_NETWORK_FAILURE
+#define QMI_WDS_CDMA_CAUSE_CODE_NETWORK_FAILURE (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_NETWORK_FAILURE
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_NETWORK_INVALID_TELESERVICE_ID:
@@ -178,8 +183,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_NETWORK_FAILURE)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_NETWORK_INVALID_TELESERVICE_ID name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_NETWORK_INVALID_TELESERVICE_ID)
-#define QMI_WDS_CDMA_CAUSE_CODE_NETWORK_INVALID_TELESERVICE_ID QMI_WMS_CDMA_CAUSE_CODE_NETWORK_INVALID_TELESERVICE_ID
+#define QMI_WDS_CDMA_CAUSE_CODE_NETWORK_INVALID_TELESERVICE_ID (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_NETWORK_INVALID_TELESERVICE_ID
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_NETWORK_OTHER:
@@ -189,8 +193,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_NETWORK_INVALID_TELESERVICE_ID)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_NETWORK_OTHER name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_NETWORK_OTHER)
-#define QMI_WDS_CDMA_CAUSE_CODE_NETWORK_OTHER QMI_WMS_CDMA_CAUSE_CODE_NETWORK_OTHER
+#define QMI_WDS_CDMA_CAUSE_CODE_NETWORK_OTHER (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_NETWORK_OTHER
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_NO_PAGE_RESPONSE:
@@ -200,8 +203,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_NETWORK_OTHER)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NO_PAGE_RESPONSE name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NO_PAGE_RESPONSE)
-#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_NO_PAGE_RESPONSE QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NO_PAGE_RESPONSE
+#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_NO_PAGE_RESPONSE (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NO_PAGE_RESPONSE
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_BUSY:
@@ -211,8 +213,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NO_PAGE_RESPONSE)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_BUSY name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_BUSY)
-#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_BUSY QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_BUSY
+#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_BUSY (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_BUSY
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_NO_ACK:
@@ -222,8 +223,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_BUSY)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NO_ACK name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NO_ACK)
-#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_NO_ACK QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NO_ACK
+#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_NO_ACK (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NO_ACK
 
 
 /**
@@ -234,8 +234,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NO_ACK)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_RESOURCE_SHORTAGE name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_RESOURCE_SHORTAGE)
-#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_RESOURCE_SHORTAGE QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_RESOURCE_SHORTAGE
+#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_RESOURCE_SHORTAGE (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_RESOURCE_SHORTAGE
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_SMS_DELIVERY_POSTPONED:
@@ -245,8 +244,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_RESOURCE_SHORTAGE)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_SMS_DELIVERY_POSTPONED name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_SMS_DELIVERY_POSTPONED)
-#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_SMS_DELIVERY_POSTPONED QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_SMS_DELIVERY_POSTPONED
+#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_SMS_DELIVERY_POSTPONED (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_SMS_DELIVERY_POSTPONED
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_OUT_OF_SERVICE:
@@ -256,8 +254,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_SMS_DELIVERY_POSTPONED)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_OUT_OF_SERVICE name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_OUT_OF_SERVICE)
-#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_OUT_OF_SERVICE QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_OUT_OF_SERVICE
+#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_OUT_OF_SERVICE (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_OUT_OF_SERVICE
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_NOT_AT_ADDRESS:
@@ -267,8 +264,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_OUT_OF_SERVICE)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NOT_AT_ADDRESS name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NOT_AT_ADDRESS)
-#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_NOT_AT_ADDRESS QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NOT_AT_ADDRESS
+#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_NOT_AT_ADDRESS (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NOT_AT_ADDRESS
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_OTHER:
@@ -278,8 +274,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_NOT_AT_ADDRESS)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_OTHER name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_OTHER)
-#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_OTHER QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_OTHER
+#define QMI_WDS_CDMA_CAUSE_CODE_DESTINATION_OTHER (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_OTHER
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_RADIO_INTERFACE_RESOURCE_SHORTAGE:
@@ -289,8 +284,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_DESTINATION_OTHER)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_RESOURCE_SHORTAGE name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_RESOURCE_SHORTAGE)
-#define QMI_WDS_CDMA_CAUSE_CODE_RADIO_INTERFACE_RESOURCE_SHORTAGE QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_RESOURCE_SHORTAGE
+#define QMI_WDS_CDMA_CAUSE_CODE_RADIO_INTERFACE_RESOURCE_SHORTAGE (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_RESOURCE_SHORTAGE
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_RADIO_INTERFACE_INCOMPATIBILITY:
@@ -300,8 +294,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_RESOURCE_SHORTAGE)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_INCOMPATIBILITY name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_INCOMPATIBILITY)
-#define QMI_WDS_CDMA_CAUSE_CODE_RADIO_INTERFACE_INCOMPATIBILITY QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_INCOMPATIBILITY
+#define QMI_WDS_CDMA_CAUSE_CODE_RADIO_INTERFACE_INCOMPATIBILITY (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_INCOMPATIBILITY
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_RADIO_INTERFACE_OTHER:
@@ -311,8 +304,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_INCOMPATIBILITY)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_OTHER name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_OTHER)
-#define QMI_WDS_CDMA_CAUSE_CODE_RADIO_INTERFACE_OTHER QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_OTHER
+#define QMI_WDS_CDMA_CAUSE_CODE_RADIO_INTERFACE_OTHER (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_OTHER
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_GENERAL_ENCODING:
@@ -322,8 +314,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_RADIO_INTERFACE_OTHER)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_GENERAL_ENCODING name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_ENCODING)
-#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_ENCODING QMI_WMS_CDMA_CAUSE_CODE_GENERAL_ENCODING
+#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_ENCODING (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_GENERAL_ENCODING
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_GENERAL_SMS_ORIGIN_DENIED:
@@ -333,8 +324,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_ENCODING)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_ORIGIN_DENIED name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_ORIGIN_DENIED)
-#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_SMS_ORIGIN_DENIED QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_ORIGIN_DENIED
+#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_SMS_ORIGIN_DENIED (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_ORIGIN_DENIED
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_GENERAL_SMS_DESTINATION_DENIED:
@@ -344,8 +334,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_ORIGIN_DENIED)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_DESTINATION_DENIED name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_DESTINATION_DENIED)
-#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_SMS_DESTINATION_DENIED QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_DESTINATION_DENIED
+#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_SMS_DESTINATION_DENIED (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_DESTINATION_DENIED
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_GENERAL_SUPPLEMENTARY_SERVICE_NOT_SUPPORTED:
@@ -355,8 +344,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_DESTINATION_DENIED)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SUPPLEMENTARY_SERVICE_NOT_SUPPORTED name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SUPPLEMENTARY_SERVICE_NOT_SUPPORTED)
-#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_SUPPLEMENTARY_SERVICE_NOT_SUPPORTED QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SUPPLEMENTARY_SERVICE_NOT_SUPPORTED
+#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_SUPPLEMENTARY_SERVICE_NOT_SUPPORTED (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SUPPLEMENTARY_SERVICE_NOT_SUPPORTED
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_GENERAL_SMS_NOT_SUPPORTED:
@@ -366,8 +354,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SUPPLEMENTARY_SERVICE_NOT_SUPP
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_NOT_SUPPORTED name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_SMS_NOT_SUPPORTED)
-#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_SMS_NOT_SUPPORTED QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_NOT_SUPPORTED
+#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_SMS_NOT_SUPPORTED (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_NOT_SUPPORTED
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_GENERAL_MISSING_EXPECTED_PARAMETER:
@@ -377,8 +364,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_SMS_SMS_NOT_SUPPORTED)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_GENERAL_MISSING_EXPECTED_PARAMETER name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_MISSING_EXPECTED_PARAMETER)
-#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_MISSING_EXPECTED_PARAMETER QMI_WMS_CDMA_CAUSE_CODE_GENERAL_MISSING_EXPECTED_PARAMETER
+#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_MISSING_EXPECTED_PARAMETER (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_GENERAL_MISSING_EXPECTED_PARAMETER
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_GENERAL_MISSING_MANDATORY_PARAMETER:
@@ -388,8 +374,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_MISSING_EXPECTED_PARAMETER)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_GENERAL_MISSING_MANDATORY_PARAMETER name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_MISSING_MANDATORY_PARAMETER)
-#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_MISSING_MANDATORY_PARAMETER QMI_WMS_CDMA_CAUSE_CODE_GENERAL_MISSING_MANDATORY_PARAMETER
+#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_MISSING_MANDATORY_PARAMETER (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_GENERAL_MISSING_MANDATORY_PARAMETER
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_GENERAL_UNRECOGNIZED_PARAMETER_VALUE:
@@ -399,8 +384,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_MISSING_MANDATORY_PARAMETER)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_GENERAL_UNRECOGNIZED_PARAMETER_VALUE name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_UNRECOGNIZED_PARAMETER_VALUE)
-#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_UNRECOGNIZED_PARAMETER_VALUE QMI_WMS_CDMA_CAUSE_CODE_GENERAL_UNRECOGNIZED_PARAMETER_VALUE
+#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_UNRECOGNIZED_PARAMETER_VALUE (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_GENERAL_UNRECOGNIZED_PARAMETER_VALUE
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_GENERAL_UNEXPECTED_PARAMETER_VALUE:
@@ -410,8 +394,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_UNRECOGNIZED_PARAMETER_VALUE)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_GENERAL_UNEXPECTED_PARAMETER_VALUE name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_UNEXPECTED_PARAMETER_VALUE)
-#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_UNEXPECTED_PARAMETER_VALUE QMI_WMS_CDMA_CAUSE_CODE_GENERAL_UNEXPECTED_PARAMETER_VALUE
+#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_UNEXPECTED_PARAMETER_VALUE (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_GENERAL_UNEXPECTED_PARAMETER_VALUE
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_GENERAL_USER_DATA_SIZE_ERROR:
@@ -421,8 +404,7 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_UNEXPECTED_PARAMETER_VALUE)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_GENERAL_USER_DATA_SIZE_ERROR name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_USER_DATA_SIZE_ERROR)
-#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_USER_DATA_SIZE_ERROR QMI_WMS_CDMA_CAUSE_CODE_GENERAL_USER_DATA_SIZE_ERROR
+#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_USER_DATA_SIZE_ERROR (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_GENERAL_USER_DATA_SIZE_ERROR
 
 /**
  * QMI_WDS_CDMA_CAUSE_CODE_GENERAL_OTHER:
@@ -432,7 +414,8 @@ G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_USER_DATA_SIZE_ERROR)
  * Since: 1.0
  * Deprecated: 1.18.0: Use the correct #QMI_WMS_CDMA_CAUSE_CODE_GENERAL_OTHER name instead.
  */
-G_DEPRECATED_FOR (QMI_WMS_CDMA_CAUSE_CODE_GENERAL_OTHER)
-#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_OTHER QMI_WMS_CDMA_CAUSE_CODE_GENERAL_OTHER
+#define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_OTHER (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_GENERAL_OTHER
+
+#endif /* QMI_DISABLE_DEPRECATED */
 
 #endif /* _LIBQMI_GLIB_QMI_COMPAT_H_ */
